# xtenors

[![PyPI - Version](https://img.shields.io/pypi/v/xtenors.svg)](https://pypi.org/project/xtenors)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/xtenors.svg)](https://pypi.org/project/xtenors)

-----

**Table of Contents**

- [Installation](#installation)
- [Overview](#overview)
- [Examples](#examples)
- [Performance](#performance)
- [License](#license)

## Installation

```console
pip install xtenors
```
## Overview

## Examples

## Performance

## License

`xtenors` is distributed under the terms of the [MIT](https://spdx.org/licenses/MIT.html) license.
